==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/dialogprintprefs.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGPRINTPREFS_H
#define INCLUDED_DIALOGPRINTPREFS_H

#include <gtk/gtk.h>
#include "configuration.h"


class PrintPreferencesDialog
{
public:
  PrintPreferencesDialog (Configuration * configuration);
  virtual ~PrintPreferencesDialog ();
  virtual int run ();
protected:
private:
  GtkWidget *dialogprintpreferences;
  GtkWidget *dialog_vbox1;
  GtkWidget *notebook1;
  GtkWidget *hbox1;
  GtkWidget *table1;
  GtkObject *spinbutton_height_adj;
  GtkWidget *spinbutton_height;
  GtkWidget *label4;
  GtkObject *spinbutton_width_adj;
  GtkWidget *spinbutton_width;
  GtkWidget *label3;
  GtkWidget *label2;
  GtkWidget *combo_format;
  GtkWidget *combo_entry_format;
  GtkWidget *label5;
  GtkWidget *vseparator1;
  GtkWidget *table2;
  GtkWidget *label6;
  GtkWidget *label7;
  GtkWidget *label8;
  GtkWidget *label9;
  GtkWidget *label10;
  GtkObject *spinbutton_left_adj;
  GtkWidget *spinbutton_left;
  GtkObject *spinbutton_right_adj;
  GtkWidget *spinbutton_right;
  GtkObject *spinbutton_top_adj;
  GtkWidget *spinbutton_top;
  GtkObject *spinbutton_bottom_adj;
  GtkWidget *spinbutton_bottom;
  GtkWidget *vseparator2;
  GtkWidget *vbox1;
  GtkWidget *checkbuttondate;
  GtkWidget *checkbutton_notes_full_width;
  GtkWidget *checkbutton_quality;
  GtkWidget *label1;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  Configuration * myconfiguration;
  static void on_spinbutton_height_changed (GtkEditable *editable, gpointer user_data);
  virtual void on_spinbutton_height ();
  static void on_spinbutton_width_changed (GtkEditable *editable, gpointer user_data);
  virtual void on_spinbutton_width ();
  static void on_combo_entry_format_changed (GtkEditable *editable, gpointer user_data);
  virtual void on_combo_entry_format ();
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_okbutton1 ();
  virtual void adjust_margin_limits ();
  virtual void set_paper_format ();
};


#endif

==> bibledit_2.2.orig.tar.gz: bibledit-2.2/src/dialogprintprefs.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#ifndef INCLUDED_DIALOGPRINTPREFS_H
#define INCLUDED_DIALOGPRINTPREFS_H


#include <gtk/gtk.h>


class PrintPreferencesDialog
{
public:
  PrintPreferencesDialog (int dummy);
  ~PrintPreferencesDialog ();
  int run ();
protected:
private:
  GtkWidget *dialogprintpreferences;
  GtkWidget *dialog_vbox1;
  GtkWidget *notebook1;
  GtkWidget *hbox1;
  GtkWidget *table1;
  GtkObject *spinbutton_height_adj;
  GtkWidget *spinbutton_height;
  GtkWidget *label4;
  GtkObject *spinbutton_width_adj;
  GtkWidget *spinbutton_width;
  GtkWidget *label3;
  GtkWidget *label2;
  GtkWidget *combo_format;
  GtkWidget *combo_entry_format;
  GtkWidget *label5;
  GtkWidget *vseparator1;
  GtkWidget *table2;
  GtkWidget *label6;
  GtkWidget *label7;
  GtkWidget *label8;
  GtkWidget *label9;
  GtkWidget *label10;
  GtkObject *spinbutton_left_adj;
  GtkWidget *spinbutton_left;
  GtkObject *spinbutton_right_adj;
  GtkWidget *spinbutton_right;
  GtkObject *spinbutton_top_adj;
  GtkWidget *spinbutton_top;
  GtkObject *spinbutton_bottom_adj;
  GtkWidget *spinbutton_bottom;
  GtkWidget *vseparator2;
  GtkWidget *vbox1;
  GtkWidget *checkbuttondate;
  GtkWidget *checkbutton_notes_full_width;
  GtkWidget *label1;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_spinbutton_height_changed (GtkEditable *editable, gpointer user_data);
  void on_spinbutton_height ();
  static void on_spinbutton_width_changed (GtkEditable *editable, gpointer user_data);
  void on_spinbutton_width ();
  static void on_combo_entry_format_changed (GtkEditable *editable, gpointer user_data);
  void on_combo_entry_format ();
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  void on_okbutton1 ();
  void adjust_margin_limits ();
  void set_paper_format ();
};


#endif
